These are internal C++ functions which wrap hypergeometric functions from GSL with vectorization. These are for particular use cases in this package, and direct access by the user is not assumed.
hyperg_1F1_vec_b(a, bvec, x)hyperg_2F1_mat_a_vec_c(Amat, b, cvec, x)
Return a list via Rcpp::List of the following:
$valEvaluation result, numeric
$errAbsolute error, numeric
$statusError code, integer
In hyperg_1F1_vec_b, these are vectors from
Rcpp::NumericVector and Rcpp::IntegerVector, whereas in
hyperg_2F1_mat_a_vec_c, they are matrices
from Rcpp::NumericMatrix and Rcpp::IntegerMatrix.
Parameters of hypergeometric functions; passed as double
Parameters of hypergeometric functions; passed as
Rcpp::NumericVector
Argument of hypergeometric functions; passed as double
Parameter of hypergeometric functions; passed as
Rcpp::NumericMatrix. Dimension must be square of the length of
cvec.
hyperg_1F1_vec_b(): wrapper of gsl_hyperg_1F1_e(), looping along bvec
hyperg_2F1_mat_a_vec_c(): wrapper of gsl_hyperg_2F1_e(), looping along Amat and
recycling cvec