These are internal C++ functions called from corresponding R
functions when use_cpp = TRUE. Direct access by the user is not
assumed. All parameters are assumed to be appropriately structured.
p_A1B1_Ed(
quantile,
A,
B,
mu,
m,
stop_on_error,
thr_margin = 100,
nthreads = 0L,
tol_zero = 2.2e-14
)p_A1B1_El(
quantile,
A,
B,
mu,
m,
stop_on_error,
thr_margin = 100L,
nthreads = 0L,
tol_zero = 2.2e-14
)
p_A1B1_Ec(
quantile,
A,
B,
mu,
m,
stop_on_error,
thr_margin = 100,
nthreads = 0L,
tol_zero = 2.2e-14
)
d_A1I1_Ed(quantile, LA, m, thr_margin = 100)
p_imhof_Ed(
quantile,
A,
B,
mu,
autoscale_args,
stop_on_error,
tol_zero,
epsabs,
epsrel,
limit
)
d_broda_Ed(
quantile,
A,
B,
mu,
autoscale_args,
stop_on_error,
tol_zero,
epsabs,
epsrel,
limit
)
d_butler_Ed(
quantile,
A,
B,
mu,
order_spa,
stop_on_error,
tol_zero,
epsabs,
epsrel,
maxiter
)
p_butler_Ed(
quantile,
A,
B,
mu,
order_spa,
stop_on_error,
tol_zero,
epsabs,
epsrel,
maxiter
)
Ap_int_E(A, mu, p_ = 1, thr_margin = 100, tol_zero = 2.2e-14)
ABpq_int_E(A, LB, mu, p_ = 1, q_ = 1, thr_margin = 100, tol_zero = 2.2e-14)
ABDpqr_int_E(
A,
LB,
D,
mu,
p_ = 1,
q_ = 1,
r_ = 1,
thr_margin = 100,
tol_zero = 2.2e-14
)
ApIq_int_cE(A, p_ = 1, q_ = 1, thr_margin = 100)
ApIq_int_nE(A, mu, p_ = 1, q_ = 1, thr_margin = 100)
ApIq_npi_cE(
LA,
bA,
p_ = 1,
q_ = 1,
m = 100L,
error_bound = TRUE,
thr_margin = 100
)
ApIq_npi_nEd(
LA,
bA,
mu,
p_ = 1,
q_ = 1,
m = 100L,
thr_margin = 100,
nthreads = 1L
)
ApBq_int_E(
A,
LB,
bB,
mu,
p_ = 1,
q_ = 1,
m = 100L,
error_bound = TRUE,
thr_margin = 100,
tol_zero = 2.2e-14
)
ApBq_npi_Ed(
A,
LB,
bA,
bB,
mu,
p_ = 1,
q_ = 1,
m = 100L,
thr_margin = 100,
nthreads = 0L,
tol_zero = 2.2e-14
)
ApBIqr_int_cEd(
A,
LB,
bB,
p_ = 1,
q_ = 1,
r_ = 1,
m = 100L,
error_bound = TRUE,
thr_margin = 100,
tol_zero = 2.2e-14
)
ApBIqr_int_nEd(
A,
LB,
bB,
mu,
p_ = 1,
q_ = 1,
r_ = 1,
m = 100L,
error_bound = TRUE,
thr_margin = 100,
nthreads = 0L,
tol_zero = 2.2e-14
)
ApBIqr_npi_Ed(
A,
LB,
bA,
bB,
mu,
p_ = 1,
q_ = 1,
r_ = 1,
m = 100L,
thr_margin = 100,
nthreads = 0L,
tol_zero = 2.2e-14
)
IpBDqr_gen_Ed(
LB,
D,
bB,
bD,
mu,
p_ = 1,
q_ = 1,
r_ = 1,
m = 100L,
thr_margin = 100,
nthreads = 0L,
tol_zero = 2.2e-14
)
ApBDqr_int_Ed(
A,
LB,
D,
bB,
bD,
mu,
p_ = 1,
q_ = 1,
r_ = 1,
m = 100L,
thr_margin = 100,
nthreads = 0L,
tol_zero = 2.2e-14
)
ApBDqr_npi_Ed(
A,
LB,
D,
bA,
bB,
bD,
mu,
p_ = 1,
q_ = 1,
r_ = 1,
m = 100L,
thr_margin = 100,
nthreads = 0L,
tol_zero = 2.2e-14
)
ApIq_npi_nEc(
LA,
bA,
mu,
p_ = 1,
q_ = 1,
m = 100L,
thr_margin = 100,
nthreads = 1L
)
ApBq_npi_Ec(
A,
LB,
bA,
bB,
mu,
p_ = 1,
q_ = 1,
m = 100L,
thr_margin = 100,
nthreads = 0L,
tol_zero = 2.2e-14
)
ApBIqr_int_nEc(
A,
LB,
bB,
mu,
p_ = 1,
q_ = 1,
r_ = 1,
m = 100L,
error_bound = TRUE,
thr_margin = 100,
nthreads = 0L,
tol_zero = 2.2e-14
)
ApBIqr_npi_Ec(
A,
LB,
bA,
bB,
mu,
p_ = 1,
q_ = 1,
r_ = 1,
m = 100L,
thr_margin = 100,
nthreads = 0L,
tol_zero = 2.2e-14
)
IpBDqr_gen_Ec(
LB,
D,
bB,
bD,
mu,
p_ = 1,
q_ = 1,
r_ = 1,
m = 100L,
thr_margin = 100,
nthreads = 0L,
tol_zero = 2.2e-14
)
ApBDqr_int_Ec(
A,
LB,
D,
bB,
bD,
mu,
p_ = 1,
q_ = 1,
r_ = 1,
m = 100L,
thr_margin = 100,
nthreads = 0L,
tol_zero = 2.2e-14
)
ApBDqr_npi_Ec(
A,
LB,
D,
bA,
bB,
bD,
mu,
p_ = 1,
q_ = 1,
r_ = 1,
m = 100L,
thr_margin = 100,
nthreads = 0L,
tol_zero = 2.2e-14
)
ApIq_npi_nEl(
LA,
bA,
mu,
p_ = 1L,
q_ = 1L,
m = 100L,
thr_margin = 100L,
nthreads = 1L
)
ApBq_npi_El(
A,
LB,
bA,
bB,
mu,
p_ = 1L,
q_ = 1L,
m = 100L,
thr_margin = 100L,
nthreads = 0L,
tol_zero = 2.2e-14
)
ApBIqr_int_nEl(
A,
LB,
bB,
mu,
p_ = 1L,
q_ = 1L,
r_ = 1L,
m = 100L,
error_bound = TRUE,
thr_margin = 100L,
nthreads = 0L,
tol_zero = 2.2e-14
)
ApBIqr_npi_El(
A,
LB,
bA,
bB,
mu,
p_ = 1L,
q_ = 1L,
r_ = 1L,
m = 100L,
thr_margin = 100L,
nthreads = 0L,
tol_zero = 2.2e-14
)
IpBDqr_gen_El(
LB,
D,
bB,
bD,
mu,
p_ = 1L,
q_ = 1L,
r_ = 1L,
m = 100L,
thr_margin = 100L,
nthreads = 0L,
tol_zero = 2.2e-14
)
ApBDqr_int_El(
A,
LB,
D,
bB,
bD,
mu,
p_ = 1L,
q_ = 1L,
r_ = 1L,
m = 100L,
thr_margin = 100L,
nthreads = 0L,
tol_zero = 2.2e-14
)
ApBDqr_npi_El(
A,
LB,
D,
bA,
bB,
bD,
mu,
p_ = 1L,
q_ = 1L,
r_ = 1L,
m = 100L,
thr_margin = 100L,
nthreads = 0L,
tol_zero = 2.2e-14
)
rqfpE(nit, A, B, D, p_, q_, r_, mu, Sigma)
All return a list via Rcpp::List of the following (as appropriate):
$ansExact moment, from double or
long double
$ansseqSeries for the moment, from
Eigen::Array
$errseqSeries of errors, from Eigen::Array
$twosidedLogical, from bool
$dimnishedLogical, from bool
Scalar of quantile \(q\), passed as double
Argument matrices passed as Eigen::Matrix.
Symmetry is assumed.
Mean vector \(\bm{\mu}\) for \(\mathbf{x}\)
passed as Eigen::Array. For d_broda_Ed(),
assumed to be rotated by the eigenvectors of
\(\mathbf{A} - q \mathbf{B}\)
Integer to specify the order of polynomials at which the series
expression is truncated. Passed as Eigen::Index
(aka std::ptrdiff_t or long long int)
bool to specify whether execution is stopped upon error in
numerical integration or root finding
Optional argument to adjust the threshold for scaling. See
“Scaling” in d1_i.
int to specify the number of threads in OpenMP-enabled
functions. See “Multithreading” in qfrm.
Tolerance against which numerical zero is determined
Eigenvalues of the argument matrices passed as Eigen::Array
Factor to which the largest absolute eigenvalue of
\(\mathbf{A} - q \mathbf{B}\) is scaled, passed as double
Optional arguments passed to gsl_integration_qagi() or
gsl_root_test_delta()
int to specify order of saddlepoint approximation
Exponents for \(\mathbf{A}\), \(\mathbf{B}\), and
\(\mathbf{D}\).
Passed as double or long double.
Scaling coefficients for \(\mathbf{A}\), \(\mathbf{B}\),
and \(\mathbf{D}\). Passed as double or long double.
bool to specify whether the error bound is returned
int to specify the number of iteration or sample size
Covariance matrix \(\mathbf{\Sigma}\) for \(\mathbf{x}\).
Passed as Eigen::Matrix.
p_A1B1_Ed(): pqfm_A1B1(), double
p_A1B1_El(): pqfm_A1B1(), long double
p_A1B1_Ec(): pqfm_A1B1(), coefficient-wise scaling
d_A1I1_Ed(): dqfm_A1I1()
p_imhof_Ed(): pqfm_imhof()
d_broda_Ed(): dqfm_broda()
d_butler_Ed(): dqfm_butler()
p_butler_Ed(): pqfm_butler()
Ap_int_E(): qfm_Ap_int()
ABpq_int_E(): qfpm_ABpq_int()
ABDpqr_int_E(): qfpm_ABDpqr_int()
ApIq_int_cE(): qfrm_ApIq_int(), central
ApIq_int_nE(): qfrm_ApIq_int(), noncentral
ApIq_npi_cE(): qfrm_ApIq_npi(), central
ApIq_npi_nEd(): qfrm_ApIq_npi(), noncentral, double
ApBq_int_E(): qfrm_ApBq_int()
ApBq_npi_Ed(): qfrm_ApBq_npi(), double
ApBIqr_int_cEd(): qfmrm_ApBIqr_int(), central
ApBIqr_int_nEd(): qfmrm_ApBIqr_int(), noncentral, double
ApBIqr_npi_Ed(): qfmrm_ApBIqr_npi(), double
IpBDqr_gen_Ed(): qfmrm_IpBDqr_gen(), double
ApBDqr_int_Ed(): qfmrm_ApBDqr_int(), double
ApBDqr_npi_Ed(): qfmrm_ApBDqr_npi(), double
ApIq_npi_nEc(): qfrm_ApIq_npi(), noncentral, coefficient-wise scaling
ApBq_npi_Ec(): qfrm_ApBq_npi(), coefficient-wise scaling
ApBIqr_int_nEc(): qfmrm_ApBIqr_int(), noncentral, coefficient-wise scaling
ApBIqr_npi_Ec(): qfmrm_ApBIqr_npi(), coefficient-wise scaling
IpBDqr_gen_Ec(): qfmrm_IpBDqr_gen(), double
ApBDqr_int_Ec(): qfmrm_ApBDqr_int(), coefficient-wise scaling
ApBDqr_npi_Ec(): qfmrm_ApBDqr_npi(), coefficient-wise scaling
ApIq_npi_nEl(): qfrm_ApIq_npi(), noncentral, long double
ApBq_npi_El(): qfrm_ApBq_npi(), long double
ApBIqr_int_nEl(): qfmrm_ApBIqr_int(), noncentral, long double
ApBIqr_npi_El(): qfmrm_ApBIqr_npi(), long double
IpBDqr_gen_El(): qfmrm_IpBDqr_gen(), long double
ApBDqr_int_El(): qfmrm_ApBDqr_int(), long double
ApBDqr_npi_El(): qfmrm_ApBDqr_npi(), long double
rqfpE(): rqfp()
ApIq_int_nmE() calls the C function
gsl_sf_hyperg_1F1() from GSL via RcppGSL.